@@ -25,7 +25,7 @@ use Encode 'encode_utf8';
 
 use experimental 'postderef';
 
-our $VERSION = "v0.0.20";
+our $VERSION = "v0.0.21";
 
 use constant {
     DEFAULT_CLEANUP_INTERVAL          => 5,
@@ -78,17 +78,9 @@ sub register ($self, $app, $config) {
     }
 
     # on workers startup:
-    my $ping_o;
     Mojo::IOLoop->next_tick(sub {
         srand();
 
-        # ping every 15 seconds
-        $ping_o = rx_defer(sub {
-            rx_timer(rand($ping_interval), $ping_interval);
-        })->pipe(
-            op_share(),
-        );
-
         my $graceful_stop_o = rx_from_event(Mojo::IOLoop->singleton, 'finish')->pipe(
             op_share(),
         );
@@ -357,14 +349,11 @@ sub register ($self, $app, $config) {
         # reject connection, if pubsub is not active
         return $self->rendered(500) if not $pubsub_connected;
 
-        # ping client at regular intervals, until client disconnects
-        $ping_o->pipe(
-            op_take_until(
-                rx_from_event($self->tx, 'finish'),
-            ),
-        )->subscribe(sub {
-            $self->send([1, 0, 0, 0, WS_PING, 'Hello World!']);
-        });
+        # send initial configuration
+        $self->send({binary => encode_json({
+            type => 'configuration',
+            pingInterval => $ping_interval,
+        })});
 
         # disconnect soon if worker stops gracefully
         $boot_emitters[int rand @boot_emitters]->subscribe(sub {
@@ -528,6 +517,8 @@ sub register ($self, $app, $config) {
                     }, "response-$channel_name-$request_id");
                 }
             }
+
+            # on $hash->{type} eq 'ping', do nothing
         });
 
         # on finish, leave all channels
